@@ -31,12 +31,18 @@ class GRPCHandler(logging.Handler):
                 t.start()
 
     async def call_user_handler(self, record, is_intercept_except):
-        if grpc_settings.LOGGING_ACTION:
-            await grpc_settings.LOGGING_ACTION(record, is_intercept_except)
+        try:
+            if grpc_settings.LOGGING_ACTION:
+                await grpc_settings.LOGGING_ACTION(record, is_intercept_except)
+        except Exception:
+            pass
 
     def call_user_handler_sync(self, record, is_intercept_except):
-        if grpc_settings.LOGGING_ACTION:
-            grpc_settings.LOGGING_ACTION(record, is_intercept_except)
+        try:
+            if grpc_settings.LOGGING_ACTION:
+                grpc_settings.LOGGING_ACTION(record, is_intercept_except)
+        except Exception:
+            pass
 
     def log_unhandled_exception(self, etype, value, tb):
 
